@@ -2,7 +2,7 @@ package Gnuplot::Simple;
 use Modern::Perl qw(2012);
 use Kavorka;
 use Types::Standard qw(ArrayRef Str);
-use Text::CSV::Slurp;
+use Text::CSV;
 use File::Slurp::Tiny qw(write_file read_file);
 use Exporter::Tidy all => [qw(exec_commands write_data)];
 use File::Temp qw(tempfile);
@@ -48,7 +48,7 @@ Example usage:
     exec_commands(
         qq{
         set terminal png
-        set output "$f"
+        set output "myfile.png"
         plot __DATA__ u 1:2 
         }, $d
     );
